#ifndef ROBODOC_ANALYSER_H
#define ROBODOC_ANALYSER_H

#include "document.h"

void                RB_Analyse_Document(
    struct RB_Document *arg_document );

#endif /* ROBODOC_ANALYSER_H */
